pub struct LiveTradeExecutor { /* private fields */ }Expand description
Live trade executor implementing the TradeExecutor trait for real-time trade execution on
an exchange. Manages trading sessions, validates operations, and maintains trade state.
Implementations
Sourceimpl LiveTradeExecutor
impl LiveTradeExecutor
Sourcepub fn update_receiver(&self) -> LiveTradeExecutorReceiver
pub fn update_receiver(&self) -> LiveTradeExecutorReceiver
Creates a new LiveTradeExecutorReceiver for subscribing to trade executor updates
including executor actions, status changes, trading state, and closed trades.
Sourcepub async fn shutdown(&self) -> Result<(), LiveTradeExecutorError>
pub async fn shutdown(&self) -> Result<(), LiveTradeExecutorError>
Shuts down the trade executor and optionally closes all running trades. This method can only be called once per executor instance.