pub trait TuiLogger: Send + Sync {
// Required method
fn log<'life0, 'async_trait>(
&'life0 self,
log_entry: String,
) -> Pin<Box<dyn Future<Output = Result<(), TuiError>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Trait for logging messages to a TUI instance.
Provides an interface for sending log entries to the TUI display.
Required Methods
Sourcefn log<'life0, 'async_trait>(
&'life0 self,
log_entry: String,
) -> Pin<Box<dyn Future<Output = Result<(), TuiError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn log<'life0, 'async_trait>(
&'life0 self,
log_entry: String,
) -> Pin<Box<dyn Future<Output = Result<(), TuiError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Sends a log entry to the TUI for display.
Returns an error if the TUI is not running or if the log message cannot be sent.